@@ -407,3 +407,9 @@ def get_all_attribute_values(url=None,url_mgr=None,source_code=None,req_mgr=None
     parse_type = parse_type or "html.parser"
     soup_mgr = get_soup_mgr(url=url,url_mgr=url_mgr,source_code=source_code,req_mgr=req_mgr,soup_mgr=soup_mgr,soup=soup)
     return soup_mgr.get_all_attribute_values(tags_list=tags_list)
+def get_soup_text(url):
+    try:
+        return get_soup_mgr(url).soup.text
+    except Exception as e:
+        print(f"{e}")
+    return ""
